@@ -113,6 +113,8 @@ if ($scheme =~ /^hg/) {
 	} else {
 		$tmp = `(cd "$ENV{'PBDIR'}" ; $vcscmd log | head -1 | cut -f2)`;
 		$tmp =~ s/^.* //;
+		# Reduce length of commit id to 8 digit
+		$tmp = substr($tmp,1,8);
 	}
 	chomp($tmp);
 	$ENV{'PBREVISION'}=$tmp;
