@@ -66,7 +66,6 @@ my $dtype = $pb->{'pbos'}->{'type'};
 my $pbrealpkg = $pb->{'realpkg'};
 my $pbver = $pb->{'ver'};
 my $pbtag = $pb->{'tag'};
-my $pbextdir = $pb->{'extdir'};
 my $pbsuf = $pb->{'pbos'}->{'suffix'};
 my $OUTPUT = shift;
 my $doit = shift;
@@ -110,8 +109,6 @@ if (((not defined $chglog) || (! -f $chglog)) && ($doit ne "yes")) {
 	$date = strftime("%Y-%m-%d", @date);
 	$ndate = &UnixDate($date,"%a", "%b", "%d", "%Y");
 	$n2date = &UnixDate($date,"%a, %d %b %Y %H:%M:%S %z");
-	# usefule mostly for test versions
-	$pbver .= $pbextdir;
 	if ($dtype eq "rpm") {
 		$ver2 = "$pbver-$pbtag";
 		print $OUTPUT "* $ndate $pbpackager->{$ENV{'PBPROJ'}} $ver2\n";
@@ -166,7 +163,7 @@ while (<INPUT>) {
 	pb_log(3,"**Ver:$ver**\n");
 	if ($ver !~ /-/) {
 		if ($first eq 1) {
-			$ver2 = "$ver$pbextdir-$pbtag";
+			$ver2 = "$ver-$pbtag";
 			$first = 0;
 		} else {
 			$ver2 = "$ver-1";
@@ -188,7 +185,7 @@ while (<INPUT>) {
 		}
 		print $OUTPUT "$pbrealpkg ($ver2) unstable; urgency=low\n";
 		print $OUTPUT "\n";
-		}
+	}
 
 	$tmp = <INPUT>;	
 	while ((defined $tmp) && ($tmp !~ /^$/)) {
